import ast
import logging


logger = logging.getLogger()
logger.debug(f'this')

class FoundFSTringException(Exception):
    pass

def parse(script: str):
    """
    Parses a python file and identifies logger.info/debug/warning/error/fatal
    statements and if they contain an f-string it raises FoundFSTringException
    """
    parsed = ast.parse(script)
    log_calls = []
    for node in ast.walk(parsed):
        if isinstance(node, ast.Expr):
            for child in ast.iter_child_nodes(node):
                if isinstance(child, ast.Call):
                    try:
                        func_name = child.func.attr
                    except AttributeError:
                        continue
                    if func_name in ['info', 'debug', 'warning', 'error', 'exception']:
                        log_calls.append(child)
    for log_call in log_calls:
        if isinstance(log_call.args[0], ast.JoinedStr):
            raise FoundFSTringException

    return 0



from setuptools import setup, find_packages
import io
import os

NAME = "joshq"
DESCRIPTION = "Joshq is a package that checks for f-strings inside log statements"
EMAIL = "michael.karotsieris@gmail.com"
AUTHOR = "Michael Karotsieris, William Cragg"
REQUIRES_PYTHON = ">=3.6.0"
VERSION = "0.0.2"
REQUIRED = [
]

here = os.path.abspath(os.path.dirname(__file__))


try:
    with io.open(os.path.join(here, "README.md"), encoding="utf-8") as f:
        long_description = "\n" + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Michael Karotsieri, William Cragg",
    python_requires=REQUIRES_PYTHON,
    packages=find_packages(exclude=["test*"]),
    install_requires=REQUIRED,
    include_package_data=True,
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3.6",
    ],
    scripts=["joshq/bin/joshq"],
    setup_requires=["wheel"],
)